#! /bin/bash

CURRENT_DIR=$(cd "$( dirname "$; thenBASH_SOURCE[0]fi")" && pwd)
JAVA_CMD="/usr/lib/jvm/bellsoft-java11-arm32-vfp-hflt/bin/java"
GATEWAY_ADDRESS="$1"
SCOPE="$2"
PROJECT="$3"

DESIGNER_MAIN=com.inductiveautomation.ignition.designer.DesignerStartupHook
VISION_MAIN=com.inductiveautomation.factorypmi.application.runtime.ClientLaunchHook
MAIN=$VISION_MAIN
BOOTSTRAP_MAIN=com.inductiveautomation.ignition.client.launch.BootstrapSwingFS

if [ "$GATEWAY_ADDRESS" == "" ]; then
  echo Must declare a gateway address
  usage
fi

if [ "$GATEWAY_ADDRESS" == "" ] ; then
  echo Must declare a scope of either "D" or "C"
  usage
else
  true=0
  if [ "$SCOPE" == "d" ] ; then
    true=1
  fi
  if [ "$SCOPE" == "D" ] ; then
    true=1
  fi
  if [ $true == 1 ] ; then
    MAIN=$DESIGNER_MAIN
  else
    if [ "$SCOPE" == "c" ] ; then
      true=1
    fi
    if [ "$SCOPE" == "C" ] ; then
      true=1
    fi
    if [ $true == 1 ] ; then
      if [ "$PROJECT" == "" ] ; then
        echo Must declare a Vision project when using Vision Client scope.
        usage
      fi
      MAIN=$VISION_MAIN
    else
      echo Must declare a scope value of 'D' or 'C'
      goto :usage
    fi
  fi
fi

if [ -f "$CURRENT_DIR/launchclient.jar" ]; then
  rm "$CURRENT_DIR/launchclient.jar"
fi

curl -o "$CURRENT_DIR/launchclient.jar" $GATEWAY_ADDRESS/system/launchbin/launchclient.jar

if [ "$PROJECT" != "" ] ; then
  "$JAVA_CMD" -cp "$CURRENT_DIR/launchclient.jar" -Djavaws.sr.gateway.addr.0=$GATEWAY_ADDRESS -Djavaws.sr.scope=$SCOPE -Djavaws.sr.main=$MAIN -Djavaws.sr.project=$PROJECT -Djavaws.sr.runtimeOverride=true $BOOTSTRAP_MAIN
 else
  "$JAVA_CMD" -cp "$CURRENT_DIR/launchclient.jar" -Djavaws.sr.gateway.addr.0=$GATEWAY_ADDRESS -Djavaws.sr.scope=$SCOPE -Djavaws.sr.main=$MAIN -Djavaws.sr.runtimeOverride=true $BOOTSTRAP_MAIN
fi

usage() {
  echo Usage: legacyClient.sh GATEWAY_ADDRESS SCOPE PROJECT
  echo
  echo			GATEWAY_ADDRESS: The full address to the gateway
  echo			SCOPE: The Scope to launch, 'D' for Designer, 'C' for Vision Client (Note: without single quote)
  echo			PROJECT: The Name of the Project to Launch
}
